===============
Contributors ✨
===============


Thanks goes to these wonderful people (`emoji key <https://allcontributors.org/docs/en/emoji-key>`_):

.. raw:: html

    <!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
    <!-- prettier-ignore-start -->
    <!-- markdownlint-disable -->
    <table>
    <tr>
        <td align="center"><a href="https://www.linkedin.com/in/alan-snow-55bb8726/"><img src="https://avatars3.githubusercontent.com/u/8699967?v=4" width="100px;" alt="Alan D. Snow"/><br /><sub><b>Alan D. Snow</b></sub></a><br /><a href="https://github.com/corteva/rioxarray/commits?author=snowman2" title="Code">💻</a> <a href="#ideas-snowman2" title="Ideas, Planning, & Feedback">🤔</a> <a href="#question-snowman2" title="Answering Questions">💬</a> <a href="https://github.com/corteva/rioxarray/issues?q=author%3Asnowman2" title="Bug reports">🐛</a> <a href="https://github.com/corteva/rioxarray/commits?author=snowman2" title="Documentation">📖</a> <a href="#example-snowman2" title="Examples">💡</a> <a href="#maintenance-snowman2" title="Maintenance">🚧</a> <a href="#review-snowman2" title="Reviewed Pull Requests">👀</a> <a href="https://github.com/corteva/rioxarray/commits?author=snowman2" title="Tests">⚠️</a></td>
        <td align="center"><a href="https://github.com/alfredoahds"><img src="https://avatars2.githubusercontent.com/u/16520854?v=4" width="100px;" alt="Alfredo Delos Santos"/><br /><sub><b>Alfredo Delos Santos</b></sub></a><br /><a href="#ideas-alfredoahds" title="Ideas, Planning, & Feedback">🤔</a> <a href="#review-alfredoahds" title="Reviewed Pull Requests">👀</a></td>
        <td align="center"><a href="https://github.com/justingruca"><img src="https://avatars2.githubusercontent.com/u/32334907?v=4" width="100px;" alt="Justin Gruca"/><br /><sub><b>Justin Gruca</b></sub></a><br /><a href="#review-justingruca" title="Reviewed Pull Requests">👀</a></td>
    </tr>
    </table>

    <!-- markdownlint-enable -->
    <!-- prettier-ignore-end -->
    <!-- ALL-CONTRIBUTORS-LIST:END -->

This project follows the `all-contributors <https://github.com/all-contributors/all-contributors>`_ specification. Contributions of any kind welcome!
